
================================
**Angst** --- Angular statistics
================================

**Angst** is a *work-in-progress* Python package for statistics on the sphere.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   points
   glossary


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
